// Import necessary functions and components from the D3.js and TopoJSON libraries
import {
  select, // To select DOM elements
  json, // To load JSON data
  geoPath, // To generate SVG path data based on GeoJSON/TopoJSON
  geoMercator, // To use the Mercator projection for the map
  scaleOrdinal, // To create an ordinal scale for coloring
  schemeCategory10, // To access a set of 10 categorical colors
} from 'd3';
import { feature } from 'topojson'; // To convert TopoJSON back to GeoJSON

// Select the SVG element in the DOM to be used for rendering the map
const svg = select('svg');

// Set up the map projection; geoMercator is commonly used for world maps
const projection = geoMercator()
  .translate([400, 300]) // Sets the translation to position the map within the SVG
  .scale(5500); // Sets the zoom level of the map

// Create a path generator using the defined projection
const pathGenerator = geoPath().projection(projection);

// Create a color scale using one of D3's categorical color schemes
const colorScale = scaleOrdinal(schemeCategory10);

// Load the geographical data in TopoJSON format from the provided URL
json(
  'https://gist.githubusercontent.com/MSushmaReddy/702fcd13d43ba8334a20d651b8858635/raw/35ab031b11be9d7261c367cde5fe61c3c8654f6e/Banglore.json',
).then((data) => {
  // Extract the feature corresponding to Bangalore from the TopoJSON data
  const bangaloreFeature = feature(
    data,
    data.objects.Bangalore,
  );

  // Bind the GeoJSON features to path elements and append them to the SVG
  svg
    .selectAll('path')
    .data(bangaloreFeature.features)
    .enter()
    .append('path')
    .attr('class', 'states') // Assign a class for potential styling
    .attr('fill', 'lightblue') // Fill color for the map
    .attr('stroke', 'black') // Border color for the map
    .attr('d', pathGenerator); // Generate the SVG path data
});
